==> ai-search-spm-1.0.4.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import queryString from 'query-string';
import { setSession, getSession, formatParams } from './utils';

var Spm = /*#__PURE__*/function () {
  function Spm(props) {
    this.appType = void 0;
    this.pageSpmName = void 0;
    this.moduleSpmName = void 0;
    this.pageSessionName = void 0;
    this.moduleSessionName = void 0;
    this.eventSessionName = void 0;
    this.eventSpmName = void 0;
    this.fromApp = void 0;
    this.onPageLoad = void 0;
    this.onEventListener = void 0;
    this.listenerEvents = void 0;
    this.isHash = void 0;
    this.fromParams = void 0;
    this.headerSpm = void 0;
    this.headerFromApp = void 0;
    this.headerFromModule = void 0;
    this.headerFromPage = void 0;
    this.headerFromEvent = void 0;
    this.headerVisitType = void 0;
    this.appType = props.appType;
    this.pageSpmName = props.pageSpmName || 'data-spm-page';
    this.moduleSpmName = props.moduleSpmName || 'data-spm-module';
    this.eventSpmName = props.eventSpmName || 'data-spm-event';
    this.pageSessionName = props.pageSessionName || 'spmPage';
    this.moduleSessionName = props.moduleSessionName || 'spmModule';
    this.eventSessionName = props.eventSessionName || 'spmEvent';
    this.fromApp = props.fromApp || 'from_app';
    this.headerSpm = props.headerSpm || 'log-spm';
    this.headerFromApp = props.headerFromApp || 'log-from-app';
    this.headerFromPage = props.headerFromPage || 'log-from-page';
    this.headerFromModule = props.headerFromModule || 'log-from-module';
    this.headerFromEvent = props.headerFromEvent || 'log-from-event';
    this.headerVisitType = props.headerVisitType || 'log-visit-type';
    this.onPageLoad = props.onPageLoad;
    this.onEventListener = props.onEventListener;
    this.listenerEvents = props.listenerEvents || ['click', 'keyup'];
    this.isHash = props.isHash || false;
    this.fromParams = props.fromParams || false; // 执行初始化

    this.init();
  }
  /**
   * 获取所属模块或者页面的spm
   * @param dom 触发事件的dom
   * @param spmType 页面、模块、事件的spm属性名
   */


  var _proto = Spm.prototype;

  _proto.findSpm = function findSpm(dom, spmType) {
    var domGet = dom;
    var spmData = '';
    var spmDom = domGet;

    while (domGet) {
      var spmValue = domGet && domGet.getAttribute(spmType);

      if (spmValue) {
        spmData = spmValue;
        spmDom = domGet;
        domGet = null;
      }

      domGet && (domGet = domGet.parentElement);
    }

    return {
      spmDom: spmDom,
      spmData: spmData
    };
  };

  _proto.location = function location(prop) {
    var _window = window,
        location = _window.location;

    if (this.isHash && prop === 'hash') {
      var hash = location.hash;
      location.hash.replace(/^#\/(.*)\?/, function (str, $1) {
        hash = "#/" + $1;
        return '';
      });
      return hash;
    }

    return location[prop];
  };

  _proto.pageLoad = function pageLoad() {
    // 获取页面埋点信息
    var pageDom = document.querySelector("[" + this.pageSpmName + "]");
    var page = pageDom && pageDom.getAttribute(this.pageSpmName);

    if (!page) {
      return;
    } // 获取应用埋点信息


    var urlParams = queryString.parse(this.location('search'));
    var fromApp = urlParams[this.fromApp]; // 获取缓存内的page、module、event埋点数据

    var fromPage = getSession('fromPage');
    var fromModule = getSession('fromModule');
    var fromEvent = getSession('fromEvent'); // 删除url中的三方应用信息

    urlParams[this.fromApp] = undefined;
    var query = queryString.stringify(urlParams);
    query = query ? "?" + query : query;
    window.history.pushState(null, '', "" + this.location('origin') + this.location('pathname') + this.location('hash') + query); // 删除session内from的数据

    setSession('fromPage');
    setSession('fromModule');
    setSession('fromEvent'); // set当前页面session

    setSession(this.moduleSessionName);
    setSession(this.eventSessionName);
    setSession(this.pageSessionName, "" + page);
    var params = formatParams(this, {
      app: this.appType,
      page: page,
      fromApp: fromApp,
      fromPage: fromPage,
      fromModule: fromModule,
      fromEvent: fromEvent
    });
    params[this.headerVisitType] = 'page';
    this.onPageLoad && this.onPageLoad(_extends({}, params));
  }
  /**
   * 埋点初始化
   */
  ;

  _proto.init = function init() {
    var _this = this;

    // 第一次加载页面
    window.onload = function () {
      _this.pageLoad();
    }; // 路由更新，页面渲染，session处理


    window.addEventListener('history', function () {
      if (history.state && history.state.key) {
        _this.pageLoad();
      }
    }); // 监听页面事件

    this.listenerEvents.forEach(function (event) {
      document.addEventListener(event, function (e) {
        var dom = e.target;
        var page = getSession(_this.pageSessionName);

        if (!dom || !page) {
          return;
        }

        var spmEventObj = _this.findSpm(dom, _this.eventSpmName);

        var spmModuleObj = _this.findSpm(spmEventObj.spmDom, _this.moduleSpmName);

        var spmEvent = spmEventObj.spmData;
        var spmModule = spmModuleObj.spmData || spmEvent; // 如果spmModule没有，则直接用spmEvent

        setSession(_this.eventSessionName, spmEvent);
        setSession(_this.moduleSessionName, spmModule);
        var params = formatParams(_this, {
          app: _this.appType,
          page: page,
          module: spmModule,
          event: spmEvent
        });
        params[_this.headerVisitType] = 'event';
        setSession('fromPage', page);
        setSession('fromModule', spmModule);
        setSession('fromEvent', spmEvent);
        _this.onEventListener && _this.onEventListener(params);
      });
    });
  };

  return Spm;
}();

export { Spm as default };

==> ai-search-spm-1.0.6.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import queryString from 'query-string';
import { setSession, getSession, formatParams } from './utils';

var Spm = /*#__PURE__*/function () {
  function Spm(props) {
    this.appType = void 0;
    this.pageSpmName = void 0;
    this.moduleSpmName = void 0;
    this.pageSessionName = void 0;
    this.moduleSessionName = void 0;
    this.eventSessionName = void 0;
    this.eventSpmName = void 0;
    this.fromApp = void 0;
    this.onPageLoad = void 0;
    this.onEventListener = void 0;
    this.listenerEvents = void 0;
    this.isHash = void 0;
    this.fromParams = void 0;
    this.headerSpm = void 0;
    this.headerFromApp = void 0;
    this.headerFromModule = void 0;
    this.headerFromPage = void 0;
    this.headerFromEvent = void 0;
    this.headerVisitType = void 0;
    this.appType = props.appType;
    this.pageSpmName = props.pageSpmName || 'data-spm-page';
    this.moduleSpmName = props.moduleSpmName || 'data-spm-module';
    this.eventSpmName = props.eventSpmName || 'data-spm-event';
    this.pageSessionName = props.pageSessionName || 'spmPage';
    this.moduleSessionName = props.moduleSessionName || 'spmModule';
    this.eventSessionName = props.eventSessionName || 'spmEvent';
    this.fromApp = props.fromApp || 'from_app';
    this.headerSpm = props.headerSpm || 'log-spm';
    this.headerFromApp = props.headerFromApp || 'log-from-app';
    this.headerFromPage = props.headerFromPage || 'log-from-page';
    this.headerFromModule = props.headerFromModule || 'log-from-module';
    this.headerFromEvent = props.headerFromEvent || 'log-from-event';
    this.headerVisitType = props.headerVisitType || 'log-visit-type';
    this.onPageLoad = props.onPageLoad;
    this.onEventListener = props.onEventListener;
    this.listenerEvents = props.listenerEvents || ['click', 'keyup'];
    this.isHash = props.isHash || false;
    this.fromParams = props.fromParams || false; // 执行初始化

    this.init();
  }
  /**
   * 获取所属模块或者页面的spm
   * @param dom 触发事件的dom
   * @param spmType 页面、模块、事件的spm属性名
   */


  var _proto = Spm.prototype;

  _proto.findSpm = function findSpm(dom, spmType) {
    var domGet = dom;
    var spmData = '';
    var spmDom = domGet;

    while (domGet) {
      var spmValue = domGet && domGet.getAttribute(spmType);

      if (spmValue) {
        spmData = spmValue;
        spmDom = domGet;
        domGet = null;
      }

      domGet && (domGet = domGet.parentElement);
    }

    return {
      spmDom: spmDom,
      spmData: spmData
    };
  };

  _proto.location = function location(prop) {
    var _window = window,
        location = _window.location;

    if (this.isHash && prop === 'hash') {
      var hash = location.hash;
      location.hash.replace(/^#\/(.*)\?/, function (str, $1) {
        hash = "#/" + $1;
        return '';
      });
      return hash;
    }

    return location[prop];
  };

  _proto.pageLoad = function pageLoad(page) {
    // 获取应用埋点信息
    var urlParams = queryString.parse(this.location('search'));
    var fromApp = urlParams[this.fromApp]; // 获取缓存内的page、module、event埋点数据

    var fromPage = getSession('fromPage');
    var fromModule = getSession('fromModule');
    var fromEvent = getSession('fromEvent'); // 删除url中的三方应用信息

    urlParams[this.fromApp] = undefined;
    var query = queryString.stringify(urlParams);
    query = query ? "?" + query : query;
    window.history.pushState(null, '', "" + this.location('origin') + this.location('pathname') + this.location('hash') + query); // 删除session内from的数据

    setSession('fromPage');
    setSession('fromModule');
    setSession('fromEvent'); // set当前页面session

    setSession(this.moduleSessionName);
    setSession(this.eventSessionName);
    setSession(this.pageSessionName, "" + page);
    var params = formatParams(this, {
      app: this.appType,
      page: page,
      fromApp: fromApp,
      fromPage: fromPage,
      fromModule: fromModule,
      fromEvent: fromEvent
    });
    params[this.headerVisitType] = 'page';
    this.onPageLoad && this.onPageLoad(_extends({}, params));
  }
  /**
   * 埋点初始化
   */
  ;

  _proto.init = function init() {
    var _this = this;

    // 第一次加载页面
    window.onload = function () {
      // 获取页面埋点信息
      var pageDom = document.querySelector("[" + _this.pageSpmName + "]");
      var page = pageDom && pageDom.getAttribute(_this.pageSpmName);

      if (page) {
        _this.pageLoad(page);
      }
    }; // 路由更新，页面渲染，session处理


    window.addEventListener('history', function () {
      if (history.state && history.state.key) {
        var pageSpmName = _this.pageSpmName;
        var itv = setInterval(function () {
          var pageDom = document.querySelector("[" + pageSpmName + "]");
          var page = pageDom && pageDom.getAttribute(pageSpmName);

          if (page) {
            clearInterval(itv);

            _this.pageLoad(page);
          }
        }, 100);
      }
    }); // 监听页面事件

    this.listenerEvents.forEach(function (event) {
      document.addEventListener(event, function (e) {
        var dom = e.target;
        var page = getSession(_this.pageSessionName);

        if (!dom || !page) {
          return;
        }

        var spmEventObj = _this.findSpm(dom, _this.eventSpmName);

        var spmModuleObj = _this.findSpm(spmEventObj.spmDom, _this.moduleSpmName);

        var spmEvent = spmEventObj.spmData;
        var spmModule = spmModuleObj.spmData || spmEvent; // 如果spmModule没有，则直接用spmEvent

        setSession(_this.eventSessionName, spmEvent);
        setSession(_this.moduleSessionName, spmModule);
        var params = formatParams(_this, {
          app: _this.appType,
          page: page,
          module: spmModule,
          event: spmEvent
        });
        params[_this.headerVisitType] = 'event';
        setSession('fromPage', page);
        setSession('fromModule', spmModule);
        setSession('fromEvent', spmEvent);
        _this.onEventListener && _this.onEventListener(params);
      });
    });
  };

  return Spm;
}();

export { Spm as default };
